@@ -217,16 +217,21 @@ populate_history (gpointer data)
        status_iter;
        status_iter = status_iter->next) {
      HistoryStatus *status;
-     GValueArray *values;
+     GHashTable *values;
      gint id;
      const gchar *text;
      gint timestamp;
 
-     values = (GValueArray *) status_iter->data;
+     values = (GHashTable *) status_iter->data;
 
-     id = g_value_get_int (g_value_array_get_nth (values, 0));
-     text = g_value_get_string (g_value_array_get_nth (values, 1));
-     timestamp = g_value_get_int (g_value_array_get_nth (values, 2));
+#define LOOKUP_INT(x) \
+    g_value_get_int(g_hash_table_lookup(values, x))
+#define LOOKUP_STR(x) \
+    g_value_get_string(g_hash_table_lookup(values, x))
+
+     id = LOOKUP_INT ("id");
+     text = LOOKUP_STR ("content");
+     timestamp = LOOKUP_INT ("start-time");
 
      status = g_slice_new0 (HistoryStatus);
      status->event_id = id;
@@ -236,7 +241,7 @@ populate_history (gpointer data)
 
      add_history_status (view, status);
 
-     g_value_array_free (values);
+     g_hash_table_destroy (values);
   }
 
   g_list_free (priv->cached_statuses);
@@ -252,9 +257,9 @@ add_history_to_list (RTComElIter *iter)
 
   if (iter && rtcom_el_iter_first (iter)) {
     do {
-      GValueArray *values;
+      GHashTable *values;
 
-      values = rtcom_el_iter_get_valuearray (
+      values = rtcom_el_iter_get_value_map (
           iter,
           "id",
           "content",
