@@ -39,8 +39,7 @@ get_contact_status (RTComEl *eventlogger,
                     RTComElQuery *query)
 {
   RTComElIter *iter;
-  GValueArray *values;
-  const gchar *free_text;
+  gchar *free_text;
   ContactStatus *status;
 
   iter = rtcom_el_get_events (eventlogger, query);
@@ -52,16 +51,14 @@ get_contact_status (RTComEl *eventlogger,
       return NULL;
   }
 
-  values = rtcom_el_iter_get_valuearray (iter, "free-text", NULL);
-  if (!values) {
+  if (!rtcom_el_iter_get_values (iter, "free-text", &free_text, NULL)) {
     g_debug("Failed to get the free-text");
     g_object_unref (iter);
     return NULL;
   }
-  free_text = g_value_get_string (g_value_array_get_nth(values, 0));
 
   status = eventlogger_util_contact_status_new ();
-  status->text = g_strdup (free_text);
+  status->text = free_text;
 
   GValue timeval = {0};
   rtcom_el_iter_get_raw (iter, "start-time", &timeval);
@@ -69,7 +66,6 @@ get_contact_status (RTComEl *eventlogger,
   g_value_unset (&timeval);
   status->start_time = get_timestamp (t);
 
-  g_value_array_free (values);
   g_object_unref (iter);
 
   return status;
@@ -194,12 +190,8 @@ eventlogger_util_get_last_status_id (RTComEl *eventlogger,
   iter = rtcom_el_get_events (eventlogger, query);
 
   if (iter && rtcom_el_iter_first (iter)) {
-    GValueArray *values;
-
-    values = rtcom_el_iter_get_valuearray (iter,
-        "id", NULL);
-    last_status_id = g_value_get_int (g_value_array_get_nth (values, 0));
-    g_value_array_free (values);
+    rtcom_el_iter_get_values (iter,
+        "id", &last_status_id, NULL);
   }
 
 END:
@@ -253,22 +245,18 @@ get_statuses_since_id (RTComEl *eventlogger,
     statuses = g_array_new (FALSE, FALSE, sizeof (gchar *));
 
     do {
-      GValueArray *values;
-      const gchar *remote_name;
-      const gchar *free_text;
+      gchar *remote_name;
+      gchar *free_text;
       gint start_time;
       gchar *timestamp;
       gchar *status;
 
-      values = rtcom_el_iter_get_valuearray (iter,
-          "remote-name",
-          "free-text",
-          "start-time",
+      rtcom_el_iter_get_values (iter,
+          "remote-name", &remote_name,
+          "free-text", &free_text,
+          "start-time", &start_time,
           NULL);
 
-      remote_name = g_value_get_string (g_value_array_get_nth (values, 0));
-      free_text = g_value_get_string (g_value_array_get_nth (values, 1));
-      start_time = g_value_get_int (g_value_array_get_nth (values, 2));
       timestamp = get_timestamp_full (start_time);
 
       status = g_strdup_printf ("%s %s\n%s\n",
@@ -276,8 +264,9 @@ get_statuses_since_id (RTComEl *eventlogger,
 
       g_array_append_val (statuses, status);
 
+      g_free (remote_name);
+      g_free (free_text);
       g_free (timestamp);
-      g_value_array_free (values);
     } while (rtcom_el_iter_next (iter));
 
     len = statuses->len;
