@@ -662,7 +662,7 @@ select_abook_cb (GtkWidget *widget,
   chooser = osso_abook_contact_chooser_new_with_capabilities (
       GTK_WINDOW (parent),
       "View status history of a contact",
-      OSSO_ABOOK_CAPS_CHAT,
+      OSSO_ABOOK_CAPS_ALL,
       OSSO_ABOOK_CONTACT_ORDER_PRESENCE); /* TODO caps ADDRESSBOOK is a bit broken */
 
   model = osso_abook_contact_chooser_get_model (
